#

##

##

    	Vitamin E

    	summary

    		One mg vitamin E (alpha-tocopherol) is equivalent
    		1 mg RRR-alpha-tocopherol
    		2 mg all rac-alpha-tocopherol.

    		Because insufficient data are available
    		to develop RDAs for infants,

    		AIs were developed based on the amount of
    		vitamin E consumed by healthy breastfed babies.

    	forecast equivalents
    		# later equivalents